<?php

namespace DsbNext\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Util;
use Teknisa\Libs\Util\NewCode;

class ParametersDashboardController {
    protected $crudService;
    protected $newCode;
    protected $service;
  
    public function __construct($connection, $environment, $util, $crudService, $newCode, $service) {
        $this->connection   = $connection;
        $this->environment  = $environment;
        $this->util         = $util;
        $this->crudService	= $crudService;
        $this->newCode	    = $newCode;
        $this->service      = $service;
    }
  
    public function addProfileAccess(Request\Row $request, Response $response) {
        $row = $request->getRow();
        try {
            $this->service->beginTransaction();
          
            $nrperfaclpainel = intval($this->newCode->getCodeByTableName("PERFACLPAINEL", $this->environment->getNrOrgTrab()));
            $params = [
                "NRPERFACLPAINEL" => $nrperfaclpainel,
                "NRPAINEL" => $row["NRPAINEL"],
                "NRPERFILACESSO" => $row["NRPERFILACESSO"],
                "CDFILIAL" => $row["CDFILIAL"],
                "IDPADRAODASH" => $row["IDPADRAODASH"],
                "NRORG" => $this->environment->getNrorg()
            ];
           $this->service->insertProfile($params);
          
           $this->service->commit();  
        }catch(\Exception $ex) {
          $this->service->rollback();
          $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function dellProfileAccess(Request\DataSet $request, Response $response) {
        $rows = $request->getParameters();
        try {
            $this->service->beginTransaction();
            foreach ($rows["dataset"] as $row) {
                $params = [
                    "NRPERFACLPAINEL" => $row["NRPERFACLPAINEL"]
                ];
                $this->service->deleteProfileAccess($params);
            }
          $this->service->commit();  
        }catch(\Exception $ex) {
          $this->service->rollback();
          $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function rowsProfileUpdate(Request\DataSet $request, Response $response) {
        $rows = $request->getParameters();
        try {
            $this->service->beginTransaction();
            foreach ($rows["dataset"] as $row) {
                $params = [
                    "NRPERFACLPAINEL" => $row["NRPERFACLPAINEL"],
                    "IDPADRAODASH" => $row["IDPADRAODASH"],
                    "CDFILIAL" => $row["CDFILIAL"]
                ];
                $this->service->rowsProfileUpdate($params);
            }
          $this->service->commit();  
        }catch(\Exception $ex) {
          $this->service->rollback();
          $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function deleteOperatorEx(Request\Row $request, Response $response) {
        $rows = $request->getRow();
        try{
            $this->service->beginTransaction();
            $cdoperador = [];
            foreach ($rows['OPERADOR'] as $row){
                if(preg_match('/^([a-z0-9A-Z]){12}$/', $row['CDOPERADOR'])){
                    array_push($cdoperador, "'".$row['CDOPERADOR']."'");
                }
            }
            $params = [
                "NRPERFILACESSO" => $rows["NRPERFILACESSO"],
                "NRPAINEL" => $rows["NRPAINEL"],
                "CDFILIAL" => $rows["CDFILIAL"]
            ];
            $this->service->deleteOperatorEx($params, $cdoperador);
            $this->service->commit();
        }catch(\Exception $ex) {
            $this->service->rollback();
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
     public function deleteOperatorExInd(Request\Row $request, Response $response) {
        $rows = $request->getRow();
        try{
            $this->service->beginTransaction();
            $nrindicpainexoper = [];
            foreach ($rows['NRINDICPAINEXCOPER'] as $row){
                array_push($nrindicpainexoper, $row['NRINDICPAINEXCOPER']);
            }
            $this->service->deleteOperatorExInd($nrindicpainexoper);
            $this->service->commit();
        }catch(\Exception $ex) {
            $this->service->rollback();
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function saveExOperadorPainel(Request\DataSet $request, Response $response) {
        $currentRow = $request->getRows()[0];
        $nrorg = $this->environment->getNrorg();
        $filterCountIndicadortf = [
            "NRPERFACLPAINEL" => $currentRow["NRPERFACLPAINEL"]
        ];
        
        
        $countIndicadortf = $this->service->countIndicadortf($filterCountIndicadortf);
        if(!empty($countIndicadortf)){
            $nrindicpainel = intval($this->newCode->getCodeByTableName('INDICPAINEL', $this->environment->getNrOrgTrab(), $countIndicadortf));
            if($nrindicpainel != 1){
                $nrindicpainel = $nrindicpainel - 1;    
            }
            $filterInsertAllIndicador = array(
                "NRINDICPAINEL" => $nrindicpainel,
                "NRPERFACLPAINEL" => $currentRow["NRPERFACLPAINEL"],
                "NRORG" => $nrorg,
                "NRPAINEL" => $currentRow["NRPAINEL"]
            );
            
            $this->service->insertAllIndicpainel($filterInsertAllIndicador);
        }
        $filterCountIndicpainel = array(
            "NRPAINEL" => $currentRow["NRPAINEL"]
        );
        
        $countIndicador = $this->service->countIndicador($filterCountIndicpainel);
        
        foreach($currentRow["OPERADOR"] as $cdoperador){
            $nrindicpainexoper = intval($this->newCode->getCodeByTableName('INDICPAINEXCOPER', $nrorg, $countIndicador));
            if($nrindicpainexoper != 1){
                $nrindicpainexoper = $nrindicpainexoper - 1;
            }
            $filterInsertOperador = array(
                "NRINDICPAINEXOPER" => $nrindicpainexoper,
                "NRPERFACLPAINEL" => $currentRow["NRPERFACLPAINEL"],
                "CDFILIAL" => $currentRow["CDFILIAL"],
                "CDOPERADOR" => $cdoperador,
                "NRORG" => $nrorg
            );
            
    		$this->service->insertExOperadorPainel($filterInsertOperador);
        }
        
    }
}