<?php
namespace DsbNext\Services;

class ParametersDashboardService {
    
    public function __construct($entityManager, $environment){
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    
    public function beginTransaction() {
        $this->connection->beginTransaction();
    }
    
    public function commit() {
        $this->connection->commit();
    }
    
    public function rollback() {
      $this->connection->rollback();
    }
  
    public function insertProfile($params) {
        $query = "INSERT INTO PERFACLPAINEL 
                              (NRPERFACLPAINEL, NRPERFILACESSO, NRPAINEL, CDFILIAL, IDPADRAODASH,  NRORG) 
                      VALUES 
                              (:NRPERFACLPAINEL, :NRPERFILACESSO,  :NRPAINEL, :CDFILIAL, :IDPADRAODASH, :NRORG)";
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $e){
            throw $e;
        };
    }
  
    public function deleteProfileAccess($params) {
        $query = "DELETE 
                    FROM PERFACLPAINEL
                   WHERE
                         NRPERFACLPAINEL = :NRPERFACLPAINEL";
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $e){
            throw $e;
        };
    }
  
    public function rowsProfileUpdate($params) {
        $query = "UPDATE PERFACLPAINEL
                     SET IDPADRAODASH = :IDPADRAODASH
                   WHERE NRPERFACLPAINEL = :NRPERFACLPAINEL
                     AND CDFILIAL = :CDFILIAL";
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $e){
            throw $e;
        };
    }
  
    public function insertIndicpanel($params){
        $query = 
            "INSERT INTO 
                    INDICPAINEL (NRINDICPAINEL, NRPERFACLPAINEL, NRINDICADORTF, IDVISUINDIC, NRORG)
                         VALUES (:NRINDICPAINEL, :NRPERFACLPAINEL, :NRINDICADORTF, :IDVISUINDIC, :NRORG)";
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $e) {
            throw $e;
        };
    }
    
    public function updateIndicpanel($params) {
        $query = "UPDATE INDICPAINEL
                    SET
                        IDVISUINDIC = :IDVISUINDIC
                  WHERE
                        NRINDICPAINEL = :NRINDICPAINEL AND
                        NRORG = :NRORG";
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $e) {
            throw $e;
        };  
    }
    
    public function deleteOperatorEx($params, $cdoperador){
        $in = '(' . implode(',', $cdoperador) .')';
        $query = "
            DELETE
              FROM INDICPAINEXCOPER I
             WHERE I.NRINDICPAINEXCOPER IN (
                SELECT IEX.NRINDICPAINEXCOPER
                  FROM INDICPAINEXCOPER IEX JOIN INDICPAINEL IP ON IEX.NRINDICPAINEL = IP.NRINDICPAINEL
                                         JOIN PERFACLPAINEL P ON P.NRPERFACLPAINEL = IP.NRPERFACLPAINEL
                 WHERE P.NRPAINEL = :NRPAINEL
                   AND P.CDFILIAL = :CDFILIAL
                   AND P.NRPERFILACESSO = :NRPERFILACESSO
                   AND IEX.CDOPERADOR IN " . $in. ")";
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function deleteOperatorExInd($nrindicpainexoper){
        $in = '(' . implode(',', $nrindicpainexoper) .')';
        $query = "
            DELETE
              FROM INDICPAINEXCOPER 
             WHERE NRINDICPAINEXCOPER IN " . $in;
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute();
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function countIndicadortf($params){
        $query =
               "SELECT COUNT(1) INDICADORESTF
                  FROM INDICADORTF I
                 WHERE I.NRINDICADORTF NOT IN (SELECT NRINDICADORTF 
                                                 FROM INDICPAINEL IP
                                                WHERE NRPERFACLPAINEL = :NRPERFACLPAINEL)";
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
            return $stmt->fetchAll()[0]["INDICADORESTF"];
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function insertAllIndicpainel($params){
        $query = 
            "INSERT INTO INDICPAINEL (NRINDICPAINEL, NRINDICADORTF, NRPERFACLPAINEL, IDVISUINDIC, NRORG)
                        SELECT :NRINDICPAINEL + ROWNUM, NRINDICADORTF, :NRPERFACLPAINEL, 'S', :NRORG
                          FROM INDICADORTF I
                         WHERE NOT EXISTS (SELECT 1 
                                            FROM INDICPAINEL IP JOIN PERFACLPAINEL P ON IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                                           WHERE P.NRPAINEL = :NRPAINEL
                                             AND IP.NRINDICADORTF = I.NRINDICADORTF
                                             AND IP.NRPERFACLPAINEL = :NRPERFACLPAINEL)";
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
}