import { Metadata } from '@zeedhi/core';
import { Modal, ModalService } from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class AfApprovalTrackingModalController {
  private afApprovalTrackingModal!: Modal;

  public async createAfApprovalTrackingModal() {
    this.afApprovalTrackingModal = await ModalService.createFromJson('/modals/afApprovalTrackingModal', true);
  }
  
  public destroyAfApprovalTrackingModal() {
    this.afApprovalTrackingModal?.destroy();
  }

  public async openAfApprovalTrackingModal({ row, column }) {
    const datasourceName = {
      CONFIRMADA: 'crudN/getAFsWithConfirmation',
      NAOCONFIRMADA: 'crudN/getAFsWithoutConfirmation',
      COMNF: 'crudN/getAFsWithNF',
      SEMNF: 'crudN/getAFsWithoutNF',
    };
    const routeDetail = datasourceName[column.name];
    if (!routeDetail) {
      return;
    }
    const dtMes = row.DTPROGENTAF.split(' ')[0];
    await this.afApprovalTrackingModal.show();
    const gridGroup = Metadata.getInstance<TekGrid>('AfApprovalTrackingGridGroup');
    gridGroup.title = column.label;
    (gridGroup.datasource as any).route = routeDetail;
    gridGroup.datasource.setFilter({
      CDFILCENTCMP: row.CDFILCENTCMP,
      INICIOMES: dtMes,
      FIMMES: dtMes,
    });
  }

  public closeAfApprovalTrackingModal() {
    this.afApprovalTrackingModal.hide();
  }
}
